Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(3672)

Unified Diff: chrome/browser/ui/views/location_bar/location_bar_view.cc

Issue 12047107: Change the SearchBox API from using the start/end margins of the location bar to using the start ma… (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Simplified LocationBarView::OnBoundsChanged Created 7 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/views/location_bar/location_bar_view.cc
diff --git a/chrome/browser/ui/views/location_bar/location_bar_view.cc b/chrome/browser/ui/views/location_bar/location_bar_view.cc
index e8a8d685ae5eb2613dbc020b14434480c4a82601..abe2a88de4902364ec05d5a67e045b2a121d510f 100644
--- a/chrome/browser/ui/views/location_bar/location_bar_view.cc
+++ b/chrome/browser/ui/views/location_bar/location_bar_view.cc
@@ -1275,14 +1275,11 @@ bool LocationBarView::HasFocus() const {
void LocationBarView::OnBoundsChanged(const gfx::Rect& previous_bounds) {
if (browser_ && browser_->instant_controller() && parent()) {
- // Pass the side margins of the location bar to the Instant Controller.
- const gfx::Rect bounds = GetBoundsInScreen();
- const gfx::Rect parent_bounds = parent()->GetBoundsInScreen();
- int start = bounds.x() - parent_bounds.x();
- int end = parent_bounds.right() - bounds.right();
- if (base::i18n::IsRTL())
- std::swap(start, end);
- browser_->instant_controller()->SetMarginSize(start, end);
+ // Pass the start margin and width of the location bar to the Instant
+ // Controller.
+ const gfx::Rect bounds_rect = bounds();
+ browser_->instant_controller()->SetStartMarginAndWidth(
+ bounds_rect.x(), bounds_rect.width());
Peter Kasting 2013/02/26 23:46:26 Nit: Rather than using a margin and width pair her
}
}
« no previous file with comments | « chrome/browser/ui/browser_instant_controller.cc ('k') | chrome/renderer/resources/extensions/searchbox_api.js » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698